@@ -60,24 +60,24 @@ See F<LICENSE>.
 
 =cut
 
-$^V eq 5.40.1 
-    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
+$^V eq 5.40.2 
+    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
                    "that PAR::Packer was built with; please rebuild PAR::Packer", 
                    $^X, $^V);
 
 1;
 
 __DATA__
-M?T5,1@$!`0````````````,`*``!````%!D``#0```#0H0````0`!30`(``)
+M?T5,1@$!`0````````````,`*``!````%!D``#0```#4H0````0`!30`(``*
 M`"@`'``;``$``'"DC@``I(X``*2.``!P````<`````0````$````!@```#0`
-M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
-M`!D````$`````0````$````````````````````8CP``&(\```4`````$```
+M```T````-````$`!``!``0``!`````0````#````F`$``)@!``"8`0``&0``
+M`!D````$`````0````$````````````````````XCP``.(\```4`````$```
 M`0```*R=``"LG0``K)T``)P"``"P`@``!@`````0```"````M)T``+2=``"T
-MG0``&`$``!@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
-M```$````4>5T9```````````````````````````!@```!````!2Y71DK)T`
-M`*R=``"LG0``5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
-M<V\N,P`````$````%`````,```!'3E4`Q==C>VM@!<]5'XH"?W?N<%)1G5<$
-M````$`````$```!'3E4```````,````"`````````#L```!-````"`````@`
+MG0``&`$``!@!```&````!`````0```!T`0``=`$``'0!```D````)`````0`
+M```$````!````!B/```8CP``&(\``"`````@````!`````0```!1Y71D````
+M```````````````````````&````$````%+E=&2LG0``K)T``*R=``!4`@``
+M5`(```0````!````!````!0````#````1TY5`*&AEIP>\<PRP#3:/ZI:]G!%
+MN82-+VQI8B]L9"UL:6YU>"UA<FUH9BYS;RXS`````#L```!-````"`````@`
 M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"`````!-````3P``
 M`%````````````````````!2`````````%,```!4````50``````````````
 M5@```%<`````````````````````````6````%D```!:`````````%L`````
@@ -87,7 +87,7 @@ M`&4```````````````````!F`````````&<```````````````````!I````
 M?JF<FUGOEWEK"4/6=E0\E"'_Y`X-.I<+P^4_+(D'<-/9<5@<K4OCP&L:GE#5
 M9-1\F4_#FR_%F[8S8MOM:W^:?`&O-.B[XY)\LP&+;T+ZUX=#1=7L9Z_,9A6,
 M)<RCX/M)S]Y'+>-'Q@'@IP(*;\7?'[[:5QO[H6Q@````````````````````
-M```````H$P````````,`"P```````*`````````#`!<`"0(`````````````
+M```````H$P````````,`"@```````*`````````#`!<`"0(`````````````
 M$@```'$``````````````!(```#A`@`````````````2````K`(`````````
 M````$@```)X"`````````````!(```![```````````````2````B@$`````
 M````````$@```!T#`````````````!(```"'```````````````2`````0``
@@ -114,17 +114,17 @@ M```2````P@``````````````$@```$0"`````````````!(````N`@``````
 M```````2````>P$`````````````$@```&@"`````````````!(````T`P``
 M```````````2````@0(`````````````$@```,D"`````````````!(```"F
 M`0`````````````2````T`(`````````````$@```(@"`````````````"(`
-M``#P`P``*#```"0````2``T`5`0``%R@````````$``8`"8$````H```````
-M`!``%P`S!```2*`````````0`!@`J`0``#@C``"0`@``$@`-`"@$````H```
-M`````"``%P!,!```R"$``%0````2``T`M00``$2@```$````$0`7`&@$``!(
-MH````````!``&``7!```B$P```0````1``\`Y@,```1+``!H`0``$@`-`*`#
-M``#\.```(`,``!(`#0"_!```D"T``'0````2``T`@@,``#0C```$````$@`-
-M`"P$```4&0```````!(`#0!U`@``&!8``/P"```2``T`700``%R@````````
-M$``8`'T$``!<H````````!``&`"V`P``\"P``*`````2``T`000``.!)```D
-M`0``$@`-`(\$``!(H````````!``%P#:`P``^"4``+0!```2``T`=`0``(Q)
-M``!4````$@`-`,<$``"L)P``1`4``!(`#0""!```A#$``'@'```2``T`DP,`
-M`,@E```P````$@`-`,0#```<(@``&`$``!(`#0`+!```'#P``#P!```2``T`
-M7`0``%R@````````$``8`)8$``!,,```.`$``!(`#0``7U]G;6]N7W-T87)T
+M``#P`P``*#```"0````2``P`5`0``%R@````````$``8`"8$````H```````
+M`!``%P`S!```2*`````````0`!@`J`0``#@C``"0`@``$@`,`"@$````H```
+M`````"``%P!,!```R"$``%0````2``P`M00``$2@```$````$0`7`&@$``!(
+MH````````!``&``7!```B$P```0````1``X`Y@,```1+``!H`0``$@`,`*`#
+M``#\.```(`,``!(`#`"_!```D"T``'0````2``P`@@,``#0C```$````$@`,
+M`"P$```4&0```````!(`#`!U`@``&!8``/P"```2``P`700``%R@````````
+M$``8`'T$``!<H````````!``&`"V`P``\"P``*`````2``P`000``.!)```D
+M`0``$@`,`(\$``!(H````````!``%P#:`P``^"4``+0!```2``P`=`0``(Q)
+M``!4````$@`,`,<$``"L)P``1`4``!(`#`""!```A#$``'@'```2``P`DP,`
+M`,@E```P````$@`,`,0#```<(@``&`$``!(`#``+!```'#P``#P!```2``P`
+M7`0``%R@````````$``8`)8$``!,,```.`$``!(`#```7U]G;6]N7W-T87)T
 M7U\`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)4
 M34-L;VYE5&%B;&4`4$Q?9&]?=6YD=6UP`%!E<FQ?<WES7W1E<FT`4&5R;%]G
 M=E]F971C:'!V`'!E<FQ?9G)E90!097)L7V=E=%]S=@!097)L7V%T9F]R:U]U
@@ -882,7 +882,7 @@ M``!!````"@```$$````+````00``````````````@;(!@;"PK`<`````A`(!
 M@;`/L0``````A;(!@;"PKG\`````=(?_?["J"8!HBO]_`0```&"-_W^PJQZ`
 MX([_?P$````DD?]_N/__?U"2_W^PJ`.`])+_?P$```"TGO]_K/__?R"?_W^P
 M__]_/*'_?["PJ(!8H?]_`0```(BB_W^PKSZ`^*G_?["J`8`0K?]_`0``````
-M````````````````````````````````````````````````````````````
+M```$````$`````$```!'3E4```````,````"````````````````````````
 M````````````````````````````````````````````````````````````
 M````````````````````````````````````````````````````````````
 M````````````````````````````````````````````````````````````
@@ -980,37 +980,37 @@ M-!,``#03```T$P``-!,``#03```T$P``-!,``#03```T$P``-!,``#03````
 M````````````````````````````````````````````````````````````
 M````````&!8````````$H```"E!!4BYP;0H`````9%```'A-````````.$X`
 M`#Q.``!84```@$T``&!0````````1%```$Q0````````;%```$=#0SH@*$=.
-M52D@,30N,2XQ(#(P,C0P-3`W`$=#0SH@*&-R;W-S=&]O;"U.1R`Q+C(V+C`N
-M-S)?.#$P,#(Q9"D@,30N,2XQ(#(P,C0P-3`W`$$T````865A8FD``2H````%
-M-RU!``8*!T$(`0D""@,,`1($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A
-M8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG
-M;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R
-M<VEO;E]R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR
-M;V1A=&$`+D%232YE>'1A8@`N05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A
-M<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O
-M;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````````
-M``````````````````````````L````!`````@```%0!``!4`0``&0``````
-M`````````0`````````3````!P````(```!P`0``<`$``"0`````````````
-M``0`````````)@````<````"````E`$``)0!```@```````````````$````
-M`````#0```#V__]O`@```+0!``"T`0``E`$```4`````````!`````0````^
-M````"P````(```!(`P``2`,``+`&```&`````P````0````0````1@````,`
-M```"````^`D``/@)```?!0`````````````!`````````$X```#___]O`@``
-M`!@/```8#P``U@````4``````````@````(```!;````_O__;P(```#P#P``
-M\`\``(`````&`````P````0`````````:@````D````"````<!```'`0``#8
-M````!0`````````$````"````',````)````0@```$@1``!($0``X`$```4`
-M```6````!`````@```!\`````0````8````H$P``*!,```P`````````````
-M``0`````````=P````$````&````-!,``#03``#D`@`````````````$````
-M!````((````!````!@```!@6```8%@``:#8`````````````"`````````"(
-M`````0````8```"`3```@$P```@```````````````0`````````C@````$`
-M```"````B$P``(A,``#X00`````````````$`````````)8````!`````@``
-M`(".``"`C@``)```````````````!`````````"A`````0``<((```"DC@``
-MI(X``'`````-``````````0`````````K`````$````"````%(\``!2/```$
-M```````````````$`````````+8````.`````P```*R=``"LG0``!```````
-M````````!`````0```#"````#P````,```"PG0``L)T```0`````````````
-M``0````$````S@````8````#````M)T``+2=```8`0``!@`````````$````
-M"````-<````!`````P```,R>``#,G@``-`$`````````````!`````0```#<
-M`````0````,`````H````*```$@```````````````0`````````X@````@`
-M```#````2*```$B@```4```````````````$`````````.<````!````,```
-M``````!(H```40```````````````0````$```#P`````P``<```````````
-MF:```#4```````````````$``````````0````,``````````````,Z@````
-3`0`````````````!````````````
+M52D@,30N,BXQ(#(P,C4P,C`W`$=#0SH@*&-R;W-S=&]O;"U.1R`Q+C(W+C!?
+M<F,Q+C=?8S@W-#-E82D@,30N,BXQ(#(P,C4P,C`W`$$T````865A8FD``2H`
+M```%-RU!``8*!T$(`0D""@,,`1($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T
+M<G1A8@`N;F]T92YG;G4N8G5I;&0M:60`+FEN=&5R<``N9VYU+FAA<V@`+F1Y
+M;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L
+M+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN
+M97AT86(`+D%232YE>&ED>``N96A?9G)A;64`+FYO=&4N04))+71A9P`N:6YI
+M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
+M+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````````````````````````
+M```````````````````````````````+````!P````(```!T`0``=`$``"0`
+M``````````````0`````````'@````$````"````F`$``)@!```9````````
+M```````!`````````"8```#V__]O`@```+0!``"T`0``E`$```0`````````
+M!`````0````P````"P````(```!(`P``2`,``+`&```%`````P````0````0
+M````.`````,````"````^`D``/@)```?!0`````````````!`````````$``
+M``#___]O`@```!@/```8#P``U@````0``````````@````(```!-````_O__
+M;P(```#P#P``\`\``(`````%`````P````0`````````7`````D````"````
+M<!```'`0``#8````!``````````$````"````&4````)````0@```$@1``!(
+M$0``X`$```0````6````!`````@```!N`````0````8````H$P``*!,```P`
+M``````````````0`````````:0````$````&````-!,``#03``#D`@``````
+M```````$````!````'0````!````!@```!@6```8%@``:#8`````````````
+M"`````````!Z`````0````8```"`3```@$P```@```````````````0`````
+M````@`````$````"````B$P``(A,``#X00`````````````$`````````(@`
+M```!`````@```(".``"`C@``)```````````````!`````````"3`````0``
+M<((```"DC@``I(X``'`````,``````````0`````````G@````$````"````
+M%(\``!2/```$```````````````$`````````*@````'`````@```!B/```8
+MCP``(```````````````!`````````"V````#@````,```"LG0``K)T```0`
+M``````````````0````$````P@````\````#````L)T``+"=```$````````
+M```````$````!````,X````&`````P```+2=``"TG0``&`$```4`````````
+M!`````@```#7`````0````,```#,G@``S)X``#0!``````````````0````$
+M````W`````$````#`````*````"@``!(```````````````$`````````.(`
+M```(`````P```$B@``!(H```%```````````````!`````````#G`````0``
+M`#``````````2*```%0```````````````$````!````\`````,``'``````
+M`````)R@```U```````````````!``````````$````#``````````````#1
+7H`````$``````````````0``````````
